import { safeJsonParse, omit, truncate } from '@trigger.dev/integration-kit';
import { ExternalSource, retry, ExternalSourceTrigger } from '@trigger.dev/sdk';
import { Octokit } from 'octokit';
import { Webhooks } from '@octokit/webhooks';
import { z } from 'zod';

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
function webhookData(data) {
  return typeof data === "object" && data !== null && typeof data.id === "number" && typeof data.config === "object";
}
__name(webhookData, "webhookData");
function createRepoEventSource(integration) {
  return new ExternalSource("HTTP", {
    id: "github.repo",
    version: "0.1.1",
    schema: z.object({
      owner: z.string(),
      repo: z.string()
    }),
    integration,
    key: (params) => `${params.owner}/${params.repo}`,
    properties: (params) => [
      {
        label: "Owner",
        text: params.owner,
        url: `https://github.com/${params.owner}`
      },
      {
        label: "Repo",
        text: params.repo,
        url: `https://github.com/${params.owner}/${params.repo}`
      }
    ],
    filter: (params) => ({
      repository: {
        full_name: [
          `${params.owner}/${params.repo}`
        ]
      }
    }),
    handler: webhookHandler,
    register: async (event, io, ctx) => {
      const { params, source: httpSource, options } = event;
      const registeredOptions = {
        event: options.event.desired
      };
      if (httpSource.active && webhookData(httpSource.data)) {
        const hasMissingOptions = Object.values(options).some((option) => option.missing.length > 0);
        if (!hasMissingOptions)
          return;
        const newWebhookData = await io.integration.updateWebhook("update-webhook", {
          owner: params.owner,
          repo: params.repo,
          hookId: httpSource.data.id,
          url: httpSource.url,
          secret: httpSource.secret,
          addEvents: options.event.missing
        });
        return {
          data: newWebhookData,
          options: registeredOptions
        };
      }
      const webhooks = await io.integration.listWebhooks("list-webhooks", {
        owner: params.owner,
        repo: params.repo
      });
      const existingWebhook = webhooks.find((w) => w.config.url === httpSource.url);
      if (existingWebhook && existingWebhook.active) {
        const updatedWebhook = await io.integration.updateWebhook("update-webhook", {
          owner: params.owner,
          repo: params.repo,
          hookId: existingWebhook.id,
          url: httpSource.url,
          secret: httpSource.secret,
          addEvents: options.event.missing
        });
        return {
          data: updatedWebhook,
          options: registeredOptions
        };
      }
      const webhook = await io.integration.createWebhook("create-webhook", {
        owner: params.owner,
        repo: params.repo,
        events: options.event.desired,
        url: httpSource.url,
        secret: httpSource.secret
      });
      return {
        data: webhook,
        options: registeredOptions
      };
    }
  });
}
__name(createRepoEventSource, "createRepoEventSource");
function createOrgEventSource(integration) {
  return new ExternalSource("HTTP", {
    id: "github.org",
    version: "0.1.1",
    integration,
    schema: z.object({
      org: z.string()
    }),
    key: (params) => params.org,
    properties: (params) => [
      {
        label: "Org",
        text: params.org,
        url: `https://github.com/${params.org}`
      }
    ],
    filter: (params) => ({
      organization: {
        login: [
          params.org
        ]
      }
    }),
    handler: webhookHandler,
    register: async (event, io, ctx) => {
      const { params, source: httpSource, options } = event;
      const registeredOptions = {
        event: options.event.desired
      };
      const hasMissingOptions = Object.values(options).some((option) => option.missing.length > 0);
      if (httpSource.active && webhookData(httpSource.data) && httpSource.secret && hasMissingOptions) {
        const existingData = httpSource.data;
        const newWebhookData = await io.integration.updateOrgWebhook("update-webhook", {
          org: params.org,
          hookId: existingData.id,
          url: httpSource.url,
          secret: httpSource.secret,
          addEvents: options.event.missing
        });
        return {
          secret: httpSource.secret,
          data: newWebhookData,
          options: registeredOptions
        };
      }
      const webhooks = await io.integration.listOrgWebhooks("list-webhooks", {
        org: params.org
      });
      const existingWebhook = webhooks.find((w) => w.config.url === httpSource.url);
      const secret = Math.random().toString(36).slice(2);
      if (existingWebhook && existingWebhook.active) {
        const updatedWebhook = await io.integration.updateOrgWebhook("update-webhook", {
          org: params.org,
          hookId: existingWebhook.id,
          url: httpSource.url,
          secret
        });
        return {
          secret,
          data: updatedWebhook,
          options: registeredOptions
        };
      }
      const webhook = await io.integration.createOrgWebhook("create-webhook", {
        org: params.org,
        events: options.event.desired,
        url: httpSource.url,
        secret
      });
      return {
        secret,
        data: webhook,
        options: registeredOptions
      };
    }
  });
}
__name(createOrgEventSource, "createOrgEventSource");
function parseBody(body) {
  if (Buffer.isBuffer(body)) {
    return safeJsonParse(body.toString());
  }
  if (typeof body === "string") {
    return safeJsonParse(body);
  }
  return body;
}
__name(parseBody, "parseBody");
async function webhookHandler(event, logger) {
  logger.debug("[inside github integration] Handling github repo event");
  const { rawEvent: request, source } = event;
  if (!request.body) {
    logger.debug("[inside github integration] No body found");
    return;
  }
  const rawBody = await request.text();
  const deliveryId = request.headers.get("x-github-delivery");
  const hookId = request.headers.get("x-github-hook-id");
  const signature = request.headers.get("x-hub-signature-256");
  if (source.secret && signature) {
    const githubWebhooks = new Webhooks({
      secret: source.secret
    });
    if (!githubWebhooks.verify(rawBody, signature)) {
      logger.debug("[inside github integration] Unable to verify the signature of the rawBody", {
        signature,
        secret: source.secret
      });
      return;
    }
  }
  const name = request.headers.get("x-github-event") ?? "unknown";
  const allHeaders = Object.fromEntries(request.headers.entries());
  const context = omit(allHeaders, [
    "x-github-event",
    "x-github-delivery",
    "x-hub-signature-256",
    "x-hub-signature",
    "content-type",
    "content-length",
    "accept",
    "accept-encoding",
    "x-forwarded-proto"
  ]);
  const payload = parseBody(rawBody);
  if (!payload) {
    logger.debug("[inside github integration] Unable to parse the rawBody");
    return;
  }
  logger.debug("[inside github integration] Returning an event for the webhook!", {
    name,
    payload,
    context
  });
  return {
    events: [
      {
        id: [
          hookId,
          deliveryId
        ].join(":"),
        source: "github.com",
        payload,
        name,
        context
      }
    ]
  };
}
__name(webhookHandler, "webhookHandler");

// src/webhook-examples.ts
var issueAssigned = {
  id: "issue.assigned",
  name: "Issue assigned",
  payload: {
    issue: {
      id: 1767861922,
      url: "https://api.github.com/repos/triggerdotdev/empty/issues/4",
      body: "This is the bod",
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      state: "open",
      title: "Fourth time lucky?",
      labels: [],
      locked: false,
      number: 4,
      node_id: "I_kwDOJyTwbc5pX26i",
      assignee: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      comments: 1,
      html_url: "https://github.com/triggerdotdev/empty/issues/4",
      assignees: [
        {
          id: 10635986,
          url: "https://api.github.com/users/matt-aitken",
          type: "User",
          login: "matt-aitken",
          node_id: "MDQ6VXNlcjEwNjM1OTg2",
          html_url: "https://github.com/matt-aitken",
          gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
          repos_url: "https://api.github.com/users/matt-aitken/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
          events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/matt-aitken/followers",
          following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
          organizations_url: "https://api.github.com/users/matt-aitken/orgs",
          subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
          received_events_url: "https://api.github.com/users/matt-aitken/received_events"
        }
      ],
      closed_at: null,
      milestone: null,
      reactions: {
        "+1": 0,
        "-1": 0,
        url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/reactions",
        eyes: 0,
        heart: 0,
        laugh: 0,
        hooray: 0,
        rocket: 0,
        confused: 0,
        total_count: 0
      },
      created_at: "2023-06-21T15:24:20Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/events",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/labels{/name}",
      updated_at: "2023-06-21T15:36:53Z",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/comments",
      state_reason: null,
      timeline_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/timeline",
      repository_url: "https://api.github.com/repos/triggerdotdev/empty",
      active_lock_reason: null,
      author_association: "MEMBER",
      performed_via_github_app: null
    },
    action: "assigned",
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    assignee: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T14:21:08Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T14:21:08Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 4,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 4,
      web_commit_signoff_required: false
    },
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    }
  }
};
var issueOpened = {
  id: "issue.opened",
  name: "Issue opened",
  payload: {
    issue: {
      id: 1754473379,
      url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21",
      body: 'This is a *big* problem:\r\n\r\n```\r\nconst foo = "bar"\r\n```',
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      state: "open",
      title: "This is a sample issue title #20",
      labels: [],
      locked: false,
      number: 21,
      node_id: "I_kwDOI-yZFc5okyOj",
      assignee: null,
      comments: 0,
      html_url: "https://github.com/ericallam/basic-starter-12k/issues/21",
      assignees: [],
      closed_at: null,
      milestone: null,
      reactions: {
        "+1": 0,
        "-1": 0,
        url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21/reactions",
        eyes: 0,
        heart: 0,
        laugh: 0,
        hooray: 0,
        rocket: 0,
        confused: 0,
        total_count: 0
      },
      created_at: "2023-06-13T09:42:02Z",
      events_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21/events",
      labels_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21/labels{/name}",
      updated_at: "2023-06-13T09:42:02Z",
      comments_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21/comments",
      state_reason: null,
      timeline_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/21/timeline",
      repository_url: "https://api.github.com/repos/ericallam/basic-starter-12k",
      active_lock_reason: null,
      author_association: "NONE",
      performed_via_github_app: null
    },
    action: "opened",
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    repository: {
      id: 602708245,
      url: "https://api.github.com/repos/ericallam/basic-starter-12k",
      fork: false,
      name: "basic-starter-12k",
      size: 0,
      forks: 0,
      owner: {
        id: 534,
        url: "https://api.github.com/users/ericallam",
        type: "User",
        login: "ericallam",
        node_id: "MDQ6VXNlcjUzNA==",
        html_url: "https://github.com/ericallam",
        gists_url: "https://api.github.com/users/ericallam/gists{/gist_id}",
        repos_url: "https://api.github.com/users/ericallam/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/534?v=4",
        events_url: "https://api.github.com/users/ericallam/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/ericallam/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/ericallam/followers",
        following_url: "https://api.github.com/users/ericallam/following{/other_user}",
        organizations_url: "https://api.github.com/users/ericallam/orgs",
        subscriptions_url: "https://api.github.com/users/ericallam/subscriptions",
        received_events_url: "https://api.github.com/users/ericallam/received_events"
      },
      topics: [],
      git_url: "git://github.com/ericallam/basic-starter-12k.git",
      license: null,
      node_id: "R_kgDOI-yZFQ",
      private: false,
      ssh_url: "git@github.com:ericallam/basic-starter-12k.git",
      svn_url: "https://github.com/ericallam/basic-starter-12k",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/ericallam/basic-starter-12k",
      keys_url: "https://api.github.com/repos/ericallam/basic-starter-12k/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/ericallam/basic-starter-12k/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/ericallam/basic-starter-12k/git/blobs{/sha}",
      clone_url: "https://github.com/ericallam/basic-starter-12k.git",
      forks_url: "https://api.github.com/repos/ericallam/basic-starter-12k/forks",
      full_name: "ericallam/basic-starter-12k",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/ericallam/basic-starter-12k/hooks",
      pulls_url: "https://api.github.com/repos/ericallam/basic-starter-12k/pulls{/number}",
      pushed_at: "2023-02-16T19:25:20Z",
      teams_url: "https://api.github.com/repos/ericallam/basic-starter-12k/teams",
      trees_url: "https://api.github.com/repos/ericallam/basic-starter-12k/git/trees{/sha}",
      created_at: "2023-02-16T19:25:19Z",
      events_url: "https://api.github.com/repos/ericallam/basic-starter-12k/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues{/number}",
      labels_url: "https://api.github.com/repos/ericallam/basic-starter-12k/labels{/name}",
      merges_url: "https://api.github.com/repos/ericallam/basic-starter-12k/merges",
      mirror_url: null,
      updated_at: "2023-02-16T19:25:19Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/ericallam/basic-starter-12k/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/ericallam/basic-starter-12k/commits{/sha}",
      compare_url: "https://api.github.com/repos/ericallam/basic-starter-12k/compare/{base}...{head}",
      description: null,
      forks_count: 0,
      is_template: false,
      open_issues: 21,
      branches_url: "https://api.github.com/repos/ericallam/basic-starter-12k/branches{/branch}",
      comments_url: "https://api.github.com/repos/ericallam/basic-starter-12k/comments{/number}",
      contents_url: "https://api.github.com/repos/ericallam/basic-starter-12k/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/ericallam/basic-starter-12k/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/ericallam/basic-starter-12k/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/ericallam/basic-starter-12k/releases{/id}",
      statuses_url: "https://api.github.com/repos/ericallam/basic-starter-12k/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/ericallam/basic-starter-12k/assignees{/user}",
      downloads_url: "https://api.github.com/repos/ericallam/basic-starter-12k/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/ericallam/basic-starter-12k/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/ericallam/basic-starter-12k/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/ericallam/basic-starter-12k/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/ericallam/basic-starter-12k/deployments",
      git_commits_url: "https://api.github.com/repos/ericallam/basic-starter-12k/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/ericallam/basic-starter-12k/subscribers",
      contributors_url: "https://api.github.com/repos/ericallam/basic-starter-12k/contributors",
      issue_events_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/ericallam/basic-starter-12k/subscription",
      collaborators_url: "https://api.github.com/repos/ericallam/basic-starter-12k/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/ericallam/basic-starter-12k/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/ericallam/basic-starter-12k/notifications{?since,all,participating}",
      open_issues_count: 21,
      web_commit_signoff_required: false
    }
  }
};
var issueCommentCreated = {
  id: "issuecomment.created",
  name: "Issue comment created",
  payload: {
    issue: {
      id: 1767861922,
      url: "https://api.github.com/repos/triggerdotdev/empty/issues/4",
      body: "This is the bod",
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      state: "open",
      title: "Fourth time lucky?",
      labels: [],
      locked: false,
      number: 4,
      node_id: "I_kwDOJyTwbc5pX26i",
      assignee: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      comments: 2,
      html_url: "https://github.com/triggerdotdev/empty/issues/4",
      assignees: [
        {
          id: 10635986,
          url: "https://api.github.com/users/matt-aitken",
          type: "User",
          login: "matt-aitken",
          node_id: "MDQ6VXNlcjEwNjM1OTg2",
          html_url: "https://github.com/matt-aitken",
          gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
          repos_url: "https://api.github.com/users/matt-aitken/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
          events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/matt-aitken/followers",
          following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
          organizations_url: "https://api.github.com/users/matt-aitken/orgs",
          subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
          received_events_url: "https://api.github.com/users/matt-aitken/received_events"
        }
      ],
      closed_at: null,
      milestone: null,
      reactions: {
        "+1": 0,
        "-1": 0,
        url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/reactions",
        eyes: 0,
        heart: 0,
        laugh: 0,
        hooray: 0,
        rocket: 0,
        confused: 0,
        total_count: 0
      },
      created_at: "2023-06-21T15:24:20Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/events",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/labels{/name}",
      updated_at: "2023-06-21T16:02:28Z",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/comments",
      state_reason: null,
      timeline_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4/timeline",
      repository_url: "https://api.github.com/repos/triggerdotdev/empty",
      active_lock_reason: null,
      author_association: "MEMBER",
      performed_via_github_app: null
    },
    action: "created",
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    comment: {
      id: 1601114728,
      url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments/1601114728",
      body: 'This is a short comment with short code snippet:\r\n\r\n```\r\nconst rick = "astley";\r\n```',
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      node_id: "IC_kwDOJyTwbc5fbxJo",
      html_url: "https://github.com/triggerdotdev/empty/issues/4#issuecomment-1601114728",
      issue_url: "https://api.github.com/repos/triggerdotdev/empty/issues/4",
      reactions: {
        "+1": 0,
        "-1": 0,
        url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments/1601114728/reactions",
        eyes: 0,
        heart: 0,
        laugh: 0,
        hooray: 0,
        rocket: 0,
        confused: 0,
        total_count: 0
      },
      created_at: "2023-06-21T16:02:27Z",
      updated_at: "2023-06-21T16:02:27Z",
      author_association: "MEMBER",
      performed_via_github_app: null
    },
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T14:21:08Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T14:21:08Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 4,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 4,
      web_commit_signoff_required: false
    },
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    }
  }
};
var starredRepo = {
  id: "star.created",
  name: "Repo starred",
  payload: {
    action: "created",
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 1,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T14:21:08Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T17:22:03Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 4,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 1,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 1,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 4,
      web_commit_signoff_required: false
    },
    starred_at: "2023-06-21T17:22:03Z",
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    }
  }
};
var newBranch = {
  id: "branch.new",
  name: "Branch created",
  payload: {
    ref: "test",
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    ref_type: "branch",
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T17:54:25Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T17:23:26Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 4,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 4,
      web_commit_signoff_required: false
    },
    description: "An empty repo that can be used to test the @trigger.dev/github integration",
    pusher_type: "user",
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    },
    master_branch: "main"
  }
};
var push = {
  id: "push",
  name: "Push",
  payload: {
    ref: "refs/heads/main",
    after: "1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
    before: "7f0b6655803858ac09ae05354a679d6dad03120c",
    forced: false,
    pusher: {
      name: "matt-aitken",
      email: "matt@mattaitken.com"
    },
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    commits: [
      {
        id: "1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
        url: "https://github.com/triggerdotdev/empty/commit/1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
        added: [],
        author: {
          name: "Matt Aitken",
          email: "matt@mattaitken.com",
          username: "matt-aitken"
        },
        message: "Updated the readme",
        removed: [],
        tree_id: "3a584b2cae2fe34a195e1fe437cc62031ddff447",
        distinct: true,
        modified: [
          "README.md"
        ],
        committer: {
          name: "Matt Aitken",
          email: "matt@mattaitken.com",
          username: "matt-aitken"
        },
        timestamp: "2023-06-21T19:27:16+01:00"
      }
    ],
    compare: "https://github.com/triggerdotdev/empty/compare/7f0b66558038...1ca6a91f4a13",
    created: false,
    deleted: false,
    base_ref: null,
    repository: {
      id: 656732269,
      url: "https://github.com/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        name: "triggerdotdev",
        type: "Organization",
        email: "hello@trigger.dev",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: 1687372039,
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: 1687357267,
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      stargazers: 0,
      updated_at: "2023-06-21T17:23:26Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 4,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      organization: "triggerdotdev",
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      master_branch: "main",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 4,
      web_commit_signoff_required: false
    },
    head_commit: {
      id: "1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
      url: "https://github.com/triggerdotdev/empty/commit/1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
      added: [],
      author: {
        name: "Matt Aitken",
        email: "matt@mattaitken.com",
        username: "matt-aitken"
      },
      message: "Updated the readme",
      removed: [],
      tree_id: "3a584b2cae2fe34a195e1fe437cc62031ddff447",
      distinct: true,
      modified: [
        "README.md"
      ],
      committer: {
        name: "Matt Aitken",
        email: "matt@mattaitken.com",
        username: "matt-aitken"
      },
      timestamp: "2023-06-21T19:27:16+01:00"
    },
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    }
  }
};
var pullRequestOpened = {
  id: "pull_request.opened",
  name: "Pull request opened",
  payload: {
    action: "opened",
    number: 5,
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T18:38:34Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T17:23:26Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 5,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 5,
      web_commit_signoff_required: false
    },
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    },
    pull_request: {
      id: 1402223044,
      url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5",
      base: {
        ref: "main",
        sha: "1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
        repo: {
          id: 656732269,
          url: "https://api.github.com/repos/triggerdotdev/empty",
          fork: false,
          name: "empty",
          size: 0,
          forks: 0,
          owner: {
            id: 95297378,
            url: "https://api.github.com/users/triggerdotdev",
            type: "Organization",
            login: "triggerdotdev",
            node_id: "O_kgDOBa4fYg",
            html_url: "https://github.com/triggerdotdev",
            gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
            repos_url: "https://api.github.com/users/triggerdotdev/repos",
            avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
            events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
            site_admin: false,
            gravatar_id: "",
            starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
            followers_url: "https://api.github.com/users/triggerdotdev/followers",
            following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
            organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
            subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
            received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
          },
          topics: [],
          git_url: "git://github.com/triggerdotdev/empty.git",
          license: null,
          node_id: "R_kgDOJyTwbQ",
          private: false,
          ssh_url: "git@github.com:triggerdotdev/empty.git",
          svn_url: "https://github.com/triggerdotdev/empty",
          archived: false,
          disabled: false,
          has_wiki: true,
          homepage: null,
          html_url: "https://github.com/triggerdotdev/empty",
          keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
          language: null,
          tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
          watchers: 0,
          blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
          clone_url: "https://github.com/triggerdotdev/empty.git",
          forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
          full_name: "triggerdotdev/empty",
          has_pages: false,
          hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
          pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
          pushed_at: "2023-06-21T18:38:34Z",
          teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
          trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
          created_at: "2023-06-21T14:21:07Z",
          events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
          has_issues: true,
          issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
          labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
          merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
          mirror_url: null,
          updated_at: "2023-06-21T17:23:26Z",
          visibility: "public",
          archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
          commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
          compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
          description: "An empty repo that can be used to test the @trigger.dev/github integration",
          forks_count: 0,
          is_template: false,
          open_issues: 5,
          branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
          comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
          contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
          git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
          git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
          has_projects: true,
          releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
          statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
          allow_forking: true,
          assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
          downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
          has_downloads: true,
          languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
          default_branch: "main",
          milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
          stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
          watchers_count: 0,
          deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
          git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
          has_discussions: false,
          subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
          allow_auto_merge: false,
          contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
          issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
          stargazers_count: 0,
          subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
          collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
          issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
          notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
          open_issues_count: 5,
          allow_merge_commit: true,
          allow_rebase_merge: true,
          allow_squash_merge: true,
          merge_commit_title: "MERGE_MESSAGE",
          allow_update_branch: false,
          merge_commit_message: "PR_TITLE",
          delete_branch_on_merge: false,
          squash_merge_commit_title: "COMMIT_OR_PR_TITLE",
          squash_merge_commit_message: "COMMIT_MESSAGES",
          web_commit_signoff_required: false,
          use_squash_pr_title_as_default: false
        },
        user: {
          id: 95297378,
          url: "https://api.github.com/users/triggerdotdev",
          type: "Organization",
          login: "triggerdotdev",
          node_id: "O_kgDOBa4fYg",
          html_url: "https://github.com/triggerdotdev",
          gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
          repos_url: "https://api.github.com/users/triggerdotdev/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
          events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/triggerdotdev/followers",
          following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
          organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
          subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
          received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
        },
        label: "triggerdotdev:main"
      },
      body: "A bit more added to the readme which could be useful",
      head: {
        ref: "test",
        sha: "073aa42afebca03c4b34361564e3976da5c65d48",
        repo: {
          id: 656732269,
          url: "https://api.github.com/repos/triggerdotdev/empty",
          fork: false,
          name: "empty",
          size: 0,
          forks: 0,
          owner: {
            id: 95297378,
            url: "https://api.github.com/users/triggerdotdev",
            type: "Organization",
            login: "triggerdotdev",
            node_id: "O_kgDOBa4fYg",
            html_url: "https://github.com/triggerdotdev",
            gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
            repos_url: "https://api.github.com/users/triggerdotdev/repos",
            avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
            events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
            site_admin: false,
            gravatar_id: "",
            starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
            followers_url: "https://api.github.com/users/triggerdotdev/followers",
            following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
            organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
            subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
            received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
          },
          topics: [],
          git_url: "git://github.com/triggerdotdev/empty.git",
          license: null,
          node_id: "R_kgDOJyTwbQ",
          private: false,
          ssh_url: "git@github.com:triggerdotdev/empty.git",
          svn_url: "https://github.com/triggerdotdev/empty",
          archived: false,
          disabled: false,
          has_wiki: true,
          homepage: null,
          html_url: "https://github.com/triggerdotdev/empty",
          keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
          language: null,
          tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
          watchers: 0,
          blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
          clone_url: "https://github.com/triggerdotdev/empty.git",
          forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
          full_name: "triggerdotdev/empty",
          has_pages: false,
          hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
          pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
          pushed_at: "2023-06-21T18:38:34Z",
          teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
          trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
          created_at: "2023-06-21T14:21:07Z",
          events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
          has_issues: true,
          issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
          labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
          merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
          mirror_url: null,
          updated_at: "2023-06-21T17:23:26Z",
          visibility: "public",
          archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
          commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
          compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
          description: "An empty repo that can be used to test the @trigger.dev/github integration",
          forks_count: 0,
          is_template: false,
          open_issues: 5,
          branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
          comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
          contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
          git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
          git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
          has_projects: true,
          releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
          statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
          allow_forking: true,
          assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
          downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
          has_downloads: true,
          languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
          default_branch: "main",
          milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
          stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
          watchers_count: 0,
          deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
          git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
          has_discussions: false,
          subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
          allow_auto_merge: false,
          contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
          issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
          stargazers_count: 0,
          subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
          collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
          issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
          notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
          open_issues_count: 5,
          allow_merge_commit: true,
          allow_rebase_merge: true,
          allow_squash_merge: true,
          merge_commit_title: "MERGE_MESSAGE",
          allow_update_branch: false,
          merge_commit_message: "PR_TITLE",
          delete_branch_on_merge: false,
          squash_merge_commit_title: "COMMIT_OR_PR_TITLE",
          squash_merge_commit_message: "COMMIT_MESSAGES",
          web_commit_signoff_required: false,
          use_squash_pr_title_as_default: false
        },
        user: {
          id: 95297378,
          url: "https://api.github.com/users/triggerdotdev",
          type: "Organization",
          login: "triggerdotdev",
          node_id: "O_kgDOBa4fYg",
          html_url: "https://github.com/triggerdotdev",
          gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
          repos_url: "https://api.github.com/users/triggerdotdev/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
          events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/triggerdotdev/followers",
          following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
          organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
          subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
          received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
        },
        label: "triggerdotdev:test"
      },
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      draft: false,
      state: "open",
      title: "Added more to the readme",
      _links: {
        html: {
          href: "https://github.com/triggerdotdev/empty/pull/5"
        },
        self: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5"
        },
        issue: {
          href: "https://api.github.com/repos/triggerdotdev/empty/issues/5"
        },
        commits: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/commits"
        },
        comments: {
          href: "https://api.github.com/repos/triggerdotdev/empty/issues/5/comments"
        },
        statuses: {
          href: "https://api.github.com/repos/triggerdotdev/empty/statuses/073aa42afebca03c4b34361564e3976da5c65d48"
        },
        review_comment: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/comments{/number}"
        },
        review_comments: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/comments"
        }
      },
      labels: [],
      locked: false,
      merged: false,
      number: 5,
      commits: 1,
      node_id: "PR_kwDOJyTwbc5TlDnE",
      assignee: null,
      comments: 0,
      diff_url: "https://github.com/triggerdotdev/empty/pull/5.diff",
      html_url: "https://github.com/triggerdotdev/empty/pull/5",
      additions: 2,
      assignees: [],
      closed_at: null,
      deletions: 0,
      issue_url: "https://api.github.com/repos/triggerdotdev/empty/issues/5",
      mergeable: null,
      merged_at: null,
      merged_by: null,
      milestone: null,
      patch_url: "https://github.com/triggerdotdev/empty/pull/5.patch",
      auto_merge: null,
      created_at: "2023-06-21T18:39:13Z",
      rebaseable: null,
      updated_at: "2023-06-21T18:39:13Z",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/commits",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/issues/5/comments",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/073aa42afebca03c4b34361564e3976da5c65d48",
      changed_files: 1,
      mergeable_state: "unknown",
      requested_teams: [],
      review_comments: 0,
      merge_commit_sha: null,
      active_lock_reason: null,
      author_association: "MEMBER",
      review_comment_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/comments{/number}",
      requested_reviewers: [],
      review_comments_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/comments",
      maintainer_can_modify: false
    }
  }
};
var pullRequestReviewSubmitted = {
  id: "pull_request_review.submitted",
  name: "Pull request review submitted",
  payload: {
    action: "submitted",
    review: {
      id: 1491475123,
      body: "This needs some work still",
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      state: "commented",
      _links: {
        html: {
          href: "https://github.com/triggerdotdev/empty/pull/5#pullrequestreview-1491475123"
        },
        pull_request: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5"
        }
      },
      node_id: "PRR_kwDOJyTwbc5Y5hqz",
      html_url: "https://github.com/triggerdotdev/empty/pull/5#pullrequestreview-1491475123",
      commit_id: "073aa42afebca03c4b34361564e3976da5c65d48",
      submitted_at: "2023-06-21T18:47:47Z",
      pull_request_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5",
      author_association: "MEMBER"
    },
    sender: {
      id: 10635986,
      url: "https://api.github.com/users/matt-aitken",
      type: "User",
      login: "matt-aitken",
      node_id: "MDQ6VXNlcjEwNjM1OTg2",
      html_url: "https://github.com/matt-aitken",
      gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
      repos_url: "https://api.github.com/users/matt-aitken/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
      events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
      site_admin: false,
      gravatar_id: "",
      starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
      followers_url: "https://api.github.com/users/matt-aitken/followers",
      following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
      organizations_url: "https://api.github.com/users/matt-aitken/orgs",
      subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
      received_events_url: "https://api.github.com/users/matt-aitken/received_events"
    },
    repository: {
      id: 656732269,
      url: "https://api.github.com/repos/triggerdotdev/empty",
      fork: false,
      name: "empty",
      size: 0,
      forks: 0,
      owner: {
        id: 95297378,
        url: "https://api.github.com/users/triggerdotdev",
        type: "Organization",
        login: "triggerdotdev",
        node_id: "O_kgDOBa4fYg",
        html_url: "https://github.com/triggerdotdev",
        gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
        repos_url: "https://api.github.com/users/triggerdotdev/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
        events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/triggerdotdev/followers",
        following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
        organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
        subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
        received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
      },
      topics: [],
      git_url: "git://github.com/triggerdotdev/empty.git",
      license: null,
      node_id: "R_kgDOJyTwbQ",
      private: false,
      ssh_url: "git@github.com:triggerdotdev/empty.git",
      svn_url: "https://github.com/triggerdotdev/empty",
      archived: false,
      disabled: false,
      has_wiki: true,
      homepage: null,
      html_url: "https://github.com/triggerdotdev/empty",
      keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
      language: null,
      tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
      watchers: 0,
      blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
      clone_url: "https://github.com/triggerdotdev/empty.git",
      forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
      full_name: "triggerdotdev/empty",
      has_pages: false,
      hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
      pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
      pushed_at: "2023-06-21T18:39:13Z",
      teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
      trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
      created_at: "2023-06-21T14:21:07Z",
      events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
      has_issues: true,
      issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
      labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
      merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
      mirror_url: null,
      updated_at: "2023-06-21T17:23:26Z",
      visibility: "public",
      archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
      compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
      description: "An empty repo that can be used to test the @trigger.dev/github integration",
      forks_count: 0,
      is_template: false,
      open_issues: 5,
      branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
      contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
      git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
      git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
      has_projects: true,
      releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
      allow_forking: true,
      assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
      downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
      has_downloads: true,
      languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
      default_branch: "main",
      milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
      stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
      watchers_count: 0,
      deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
      git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
      has_discussions: false,
      subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
      contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
      issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
      stargazers_count: 0,
      subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
      collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
      issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
      notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
      open_issues_count: 5,
      web_commit_signoff_required: false
    },
    organization: {
      id: 95297378,
      url: "https://api.github.com/orgs/triggerdotdev",
      login: "triggerdotdev",
      node_id: "O_kgDOBa4fYg",
      hooks_url: "https://api.github.com/orgs/triggerdotdev/hooks",
      repos_url: "https://api.github.com/orgs/triggerdotdev/repos",
      avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
      events_url: "https://api.github.com/orgs/triggerdotdev/events",
      issues_url: "https://api.github.com/orgs/triggerdotdev/issues",
      description: "",
      members_url: "https://api.github.com/orgs/triggerdotdev/members{/member}",
      public_members_url: "https://api.github.com/orgs/triggerdotdev/public_members{/member}"
    },
    pull_request: {
      id: 1402223044,
      url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5",
      base: {
        ref: "main",
        sha: "1ca6a91f4a1385e448364a5de1960a3da60d3fe2",
        repo: {
          id: 656732269,
          url: "https://api.github.com/repos/triggerdotdev/empty",
          fork: false,
          name: "empty",
          size: 0,
          forks: 0,
          owner: {
            id: 95297378,
            url: "https://api.github.com/users/triggerdotdev",
            type: "Organization",
            login: "triggerdotdev",
            node_id: "O_kgDOBa4fYg",
            html_url: "https://github.com/triggerdotdev",
            gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
            repos_url: "https://api.github.com/users/triggerdotdev/repos",
            avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
            events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
            site_admin: false,
            gravatar_id: "",
            starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
            followers_url: "https://api.github.com/users/triggerdotdev/followers",
            following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
            organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
            subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
            received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
          },
          topics: [],
          git_url: "git://github.com/triggerdotdev/empty.git",
          license: null,
          node_id: "R_kgDOJyTwbQ",
          private: false,
          ssh_url: "git@github.com:triggerdotdev/empty.git",
          svn_url: "https://github.com/triggerdotdev/empty",
          archived: false,
          disabled: false,
          has_wiki: true,
          homepage: null,
          html_url: "https://github.com/triggerdotdev/empty",
          keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
          language: null,
          tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
          watchers: 0,
          blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
          clone_url: "https://github.com/triggerdotdev/empty.git",
          forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
          full_name: "triggerdotdev/empty",
          has_pages: false,
          hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
          pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
          pushed_at: "2023-06-21T18:39:13Z",
          teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
          trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
          created_at: "2023-06-21T14:21:07Z",
          events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
          has_issues: true,
          issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
          labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
          merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
          mirror_url: null,
          updated_at: "2023-06-21T17:23:26Z",
          visibility: "public",
          archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
          commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
          compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
          description: "An empty repo that can be used to test the @trigger.dev/github integration",
          forks_count: 0,
          is_template: false,
          open_issues: 5,
          branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
          comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
          contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
          git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
          git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
          has_projects: true,
          releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
          statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
          allow_forking: true,
          assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
          downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
          has_downloads: true,
          languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
          default_branch: "main",
          milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
          stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
          watchers_count: 0,
          deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
          git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
          has_discussions: false,
          subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
          allow_auto_merge: false,
          contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
          issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
          stargazers_count: 0,
          subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
          collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
          issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
          notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
          open_issues_count: 5,
          allow_merge_commit: true,
          allow_rebase_merge: true,
          allow_squash_merge: true,
          merge_commit_title: "MERGE_MESSAGE",
          allow_update_branch: false,
          merge_commit_message: "PR_TITLE",
          delete_branch_on_merge: false,
          squash_merge_commit_title: "COMMIT_OR_PR_TITLE",
          squash_merge_commit_message: "COMMIT_MESSAGES",
          web_commit_signoff_required: false,
          use_squash_pr_title_as_default: false
        },
        user: {
          id: 95297378,
          url: "https://api.github.com/users/triggerdotdev",
          type: "Organization",
          login: "triggerdotdev",
          node_id: "O_kgDOBa4fYg",
          html_url: "https://github.com/triggerdotdev",
          gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
          repos_url: "https://api.github.com/users/triggerdotdev/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
          events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/triggerdotdev/followers",
          following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
          organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
          subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
          received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
        },
        label: "triggerdotdev:main"
      },
      body: "A bit more added to the readme which could be useful",
      head: {
        ref: "test",
        sha: "073aa42afebca03c4b34361564e3976da5c65d48",
        repo: {
          id: 656732269,
          url: "https://api.github.com/repos/triggerdotdev/empty",
          fork: false,
          name: "empty",
          size: 0,
          forks: 0,
          owner: {
            id: 95297378,
            url: "https://api.github.com/users/triggerdotdev",
            type: "Organization",
            login: "triggerdotdev",
            node_id: "O_kgDOBa4fYg",
            html_url: "https://github.com/triggerdotdev",
            gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
            repos_url: "https://api.github.com/users/triggerdotdev/repos",
            avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
            events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
            site_admin: false,
            gravatar_id: "",
            starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
            followers_url: "https://api.github.com/users/triggerdotdev/followers",
            following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
            organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
            subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
            received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
          },
          topics: [],
          git_url: "git://github.com/triggerdotdev/empty.git",
          license: null,
          node_id: "R_kgDOJyTwbQ",
          private: false,
          ssh_url: "git@github.com:triggerdotdev/empty.git",
          svn_url: "https://github.com/triggerdotdev/empty",
          archived: false,
          disabled: false,
          has_wiki: true,
          homepage: null,
          html_url: "https://github.com/triggerdotdev/empty",
          keys_url: "https://api.github.com/repos/triggerdotdev/empty/keys{/key_id}",
          language: null,
          tags_url: "https://api.github.com/repos/triggerdotdev/empty/tags",
          watchers: 0,
          blobs_url: "https://api.github.com/repos/triggerdotdev/empty/git/blobs{/sha}",
          clone_url: "https://github.com/triggerdotdev/empty.git",
          forks_url: "https://api.github.com/repos/triggerdotdev/empty/forks",
          full_name: "triggerdotdev/empty",
          has_pages: false,
          hooks_url: "https://api.github.com/repos/triggerdotdev/empty/hooks",
          pulls_url: "https://api.github.com/repos/triggerdotdev/empty/pulls{/number}",
          pushed_at: "2023-06-21T18:39:13Z",
          teams_url: "https://api.github.com/repos/triggerdotdev/empty/teams",
          trees_url: "https://api.github.com/repos/triggerdotdev/empty/git/trees{/sha}",
          created_at: "2023-06-21T14:21:07Z",
          events_url: "https://api.github.com/repos/triggerdotdev/empty/events",
          has_issues: true,
          issues_url: "https://api.github.com/repos/triggerdotdev/empty/issues{/number}",
          labels_url: "https://api.github.com/repos/triggerdotdev/empty/labels{/name}",
          merges_url: "https://api.github.com/repos/triggerdotdev/empty/merges",
          mirror_url: null,
          updated_at: "2023-06-21T17:23:26Z",
          visibility: "public",
          archive_url: "https://api.github.com/repos/triggerdotdev/empty/{archive_format}{/ref}",
          commits_url: "https://api.github.com/repos/triggerdotdev/empty/commits{/sha}",
          compare_url: "https://api.github.com/repos/triggerdotdev/empty/compare/{base}...{head}",
          description: "An empty repo that can be used to test the @trigger.dev/github integration",
          forks_count: 0,
          is_template: false,
          open_issues: 5,
          branches_url: "https://api.github.com/repos/triggerdotdev/empty/branches{/branch}",
          comments_url: "https://api.github.com/repos/triggerdotdev/empty/comments{/number}",
          contents_url: "https://api.github.com/repos/triggerdotdev/empty/contents/{+path}",
          git_refs_url: "https://api.github.com/repos/triggerdotdev/empty/git/refs{/sha}",
          git_tags_url: "https://api.github.com/repos/triggerdotdev/empty/git/tags{/sha}",
          has_projects: true,
          releases_url: "https://api.github.com/repos/triggerdotdev/empty/releases{/id}",
          statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/{sha}",
          allow_forking: true,
          assignees_url: "https://api.github.com/repos/triggerdotdev/empty/assignees{/user}",
          downloads_url: "https://api.github.com/repos/triggerdotdev/empty/downloads",
          has_downloads: true,
          languages_url: "https://api.github.com/repos/triggerdotdev/empty/languages",
          default_branch: "main",
          milestones_url: "https://api.github.com/repos/triggerdotdev/empty/milestones{/number}",
          stargazers_url: "https://api.github.com/repos/triggerdotdev/empty/stargazers",
          watchers_count: 0,
          deployments_url: "https://api.github.com/repos/triggerdotdev/empty/deployments",
          git_commits_url: "https://api.github.com/repos/triggerdotdev/empty/git/commits{/sha}",
          has_discussions: false,
          subscribers_url: "https://api.github.com/repos/triggerdotdev/empty/subscribers",
          allow_auto_merge: false,
          contributors_url: "https://api.github.com/repos/triggerdotdev/empty/contributors",
          issue_events_url: "https://api.github.com/repos/triggerdotdev/empty/issues/events{/number}",
          stargazers_count: 0,
          subscription_url: "https://api.github.com/repos/triggerdotdev/empty/subscription",
          collaborators_url: "https://api.github.com/repos/triggerdotdev/empty/collaborators{/collaborator}",
          issue_comment_url: "https://api.github.com/repos/triggerdotdev/empty/issues/comments{/number}",
          notifications_url: "https://api.github.com/repos/triggerdotdev/empty/notifications{?since,all,participating}",
          open_issues_count: 5,
          allow_merge_commit: true,
          allow_rebase_merge: true,
          allow_squash_merge: true,
          merge_commit_title: "MERGE_MESSAGE",
          allow_update_branch: false,
          merge_commit_message: "PR_TITLE",
          delete_branch_on_merge: false,
          squash_merge_commit_title: "COMMIT_OR_PR_TITLE",
          squash_merge_commit_message: "COMMIT_MESSAGES",
          web_commit_signoff_required: false,
          use_squash_pr_title_as_default: false
        },
        user: {
          id: 95297378,
          url: "https://api.github.com/users/triggerdotdev",
          type: "Organization",
          login: "triggerdotdev",
          node_id: "O_kgDOBa4fYg",
          html_url: "https://github.com/triggerdotdev",
          gists_url: "https://api.github.com/users/triggerdotdev/gists{/gist_id}",
          repos_url: "https://api.github.com/users/triggerdotdev/repos",
          avatar_url: "https://avatars.githubusercontent.com/u/95297378?v=4",
          events_url: "https://api.github.com/users/triggerdotdev/events{/privacy}",
          site_admin: false,
          gravatar_id: "",
          starred_url: "https://api.github.com/users/triggerdotdev/starred{/owner}{/repo}",
          followers_url: "https://api.github.com/users/triggerdotdev/followers",
          following_url: "https://api.github.com/users/triggerdotdev/following{/other_user}",
          organizations_url: "https://api.github.com/users/triggerdotdev/orgs",
          subscriptions_url: "https://api.github.com/users/triggerdotdev/subscriptions",
          received_events_url: "https://api.github.com/users/triggerdotdev/received_events"
        },
        label: "triggerdotdev:test"
      },
      user: {
        id: 10635986,
        url: "https://api.github.com/users/matt-aitken",
        type: "User",
        login: "matt-aitken",
        node_id: "MDQ6VXNlcjEwNjM1OTg2",
        html_url: "https://github.com/matt-aitken",
        gists_url: "https://api.github.com/users/matt-aitken/gists{/gist_id}",
        repos_url: "https://api.github.com/users/matt-aitken/repos",
        avatar_url: "https://avatars.githubusercontent.com/u/10635986?v=4",
        events_url: "https://api.github.com/users/matt-aitken/events{/privacy}",
        site_admin: false,
        gravatar_id: "",
        starred_url: "https://api.github.com/users/matt-aitken/starred{/owner}{/repo}",
        followers_url: "https://api.github.com/users/matt-aitken/followers",
        following_url: "https://api.github.com/users/matt-aitken/following{/other_user}",
        organizations_url: "https://api.github.com/users/matt-aitken/orgs",
        subscriptions_url: "https://api.github.com/users/matt-aitken/subscriptions",
        received_events_url: "https://api.github.com/users/matt-aitken/received_events"
      },
      draft: false,
      state: "open",
      title: "Added more to the readme",
      _links: {
        html: {
          href: "https://github.com/triggerdotdev/empty/pull/5"
        },
        self: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5"
        },
        issue: {
          href: "https://api.github.com/repos/triggerdotdev/empty/issues/5"
        },
        commits: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/commits"
        },
        comments: {
          href: "https://api.github.com/repos/triggerdotdev/empty/issues/5/comments"
        },
        statuses: {
          href: "https://api.github.com/repos/triggerdotdev/empty/statuses/073aa42afebca03c4b34361564e3976da5c65d48"
        },
        review_comment: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/comments{/number}"
        },
        review_comments: {
          href: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/comments"
        }
      },
      labels: [],
      locked: false,
      number: 5,
      node_id: "PR_kwDOJyTwbc5TlDnE",
      assignee: null,
      diff_url: "https://github.com/triggerdotdev/empty/pull/5.diff",
      html_url: "https://github.com/triggerdotdev/empty/pull/5",
      assignees: [],
      closed_at: null,
      issue_url: "https://api.github.com/repos/triggerdotdev/empty/issues/5",
      merged_at: null,
      milestone: null,
      patch_url: "https://github.com/triggerdotdev/empty/pull/5.patch",
      auto_merge: null,
      created_at: "2023-06-21T18:39:13Z",
      updated_at: "2023-06-21T18:47:47Z",
      commits_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/commits",
      comments_url: "https://api.github.com/repos/triggerdotdev/empty/issues/5/comments",
      statuses_url: "https://api.github.com/repos/triggerdotdev/empty/statuses/073aa42afebca03c4b34361564e3976da5c65d48",
      requested_teams: [],
      merge_commit_sha: "f146c57c260778db17300c47c366bce0e2dbd53d",
      active_lock_reason: null,
      author_association: "MEMBER",
      review_comment_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/comments{/number}",
      requested_reviewers: [],
      review_comments_url: "https://api.github.com/repos/triggerdotdev/empty/pulls/5/comments"
    }
  }
};

// src/propertyHelpers.ts
function repoProperties(params) {
  return [
    {
      label: "Owner",
      text: params.owner
    },
    {
      label: "Repo",
      text: params.repo
    }
  ];
}
__name(repoProperties, "repoProperties");
function issueProperties(params) {
  return [
    {
      label: "Issue",
      text: `#${params.issueNumber}`
    }
  ];
}
__name(issueProperties, "issueProperties");

// src/issues.ts
var _Issues = class _Issues {
  constructor(runTask) {
    this.runTask = runTask;
  }
  create(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.issues.create({
        owner: params.owner,
        repo: params.repo,
        title: params.title
      });
      return result.data;
    }, {
      name: "Create Issue",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Title",
          text: params.title
        }
      ]
    }, onError);
  }
  addAssignees(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.issues.addAssignees({
        owner: params.owner,
        repo: params.repo,
        issue_number: params.issueNumber,
        assignees: params.assignees
      });
      return result.data;
    }, {
      name: "Add Issue Assignees",
      params,
      properties: [
        ...repoProperties(params),
        ...issueProperties(params),
        {
          label: "assignees",
          text: params.assignees.join(", ")
        }
      ]
    }, onError);
  }
  addLabels(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.issues.addLabels({
        owner: params.owner,
        repo: params.repo,
        issue_number: params.issueNumber,
        labels: params.labels
      });
      return result.data;
    }, {
      name: "Add Issue Labels",
      params,
      properties: [
        ...repoProperties(params),
        ...issueProperties(params),
        {
          label: "Labels",
          text: params.labels.join(", ")
        }
      ]
    }, onError);
  }
  createComment(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.issues.createComment({
        owner: params.owner,
        repo: params.repo,
        body: params.body,
        issue_number: params.issueNumber
      });
      return result.data;
    }, {
      name: "Create Issue Comment",
      params,
      properties: [
        ...repoProperties(params),
        ...issueProperties(params)
      ]
    }, onError);
  }
  get(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.issues.get({
        owner: params.owner,
        repo: params.repo,
        issue_number: params.issueNumber
      });
      return result.data;
    }, {
      name: "Get Issue",
      params,
      properties: [
        ...repoProperties(params),
        ...issueProperties(params)
      ]
    }, onError);
  }
};
__name(_Issues, "Issues");
var Issues = _Issues;

// src/repos.ts
var _Repos = class _Repos {
  constructor(runTask) {
    this.runTask = runTask;
  }
  get(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.repos.get({
        owner: params.owner,
        repo: params.repo,
        headers: {
          "x-trigger-attempt": String(task.attempts)
        }
      });
      return result.data;
    }, {
      name: "Get Repo",
      params,
      properties: [
        {
          label: "Repo",
          text: params.repo
        }
      ]
    }, onError);
  }
  updateWebhook(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.repos.updateWebhook({
        owner: params.owner,
        repo: params.repo,
        hook_id: params.hookId,
        config: {
          content_type: "json",
          url: params.url,
          secret: params.secret
        },
        add_events: params.addEvents
      });
      return result.data;
    }, {
      name: "Update Webhook",
      params,
      properties: [
        {
          label: "Owner",
          text: params.owner
        },
        {
          label: "Repo",
          text: params.repo
        },
        {
          label: "Hook ID",
          text: String(params.hookId)
        }
      ]
    }, onError);
  }
  createWebhook(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.repos.createWebhook({
        owner: params.owner,
        repo: params.repo,
        config: {
          content_type: "json",
          url: params.url,
          secret: params.secret
        },
        events: params.events
      });
      return result.data;
    }, {
      name: "Create Webhook",
      params,
      properties: [
        {
          label: "Owner",
          text: params.owner
        },
        {
          label: "Repo",
          text: params.repo
        },
        {
          label: "Events",
          text: params.events.join(", ")
        }
      ]
    }, onError);
  }
  listWebhooks(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.repos.listWebhooks({
        owner: params.owner,
        repo: params.repo
      });
      return result.data;
    }, {
      name: "List Webhooks",
      params,
      properties: [
        {
          label: "Owner",
          text: params.owner
        },
        {
          label: "Repo",
          text: params.repo
        }
      ]
    }, onError);
  }
};
__name(_Repos, "Repos");
var Repos = _Repos;

// src/reactions.ts
var _Reactions = class _Reactions {
  constructor(runTask) {
    this.runTask = runTask;
  }
  createForIssueComment(key, params) {
    let emoji = "";
    switch (params.content) {
      case "+1":
        emoji = "\u{1F44D}";
        break;
      case "-1":
        emoji = "\u{1F44E}";
        break;
      case "laugh":
        emoji = "\u{1F604}";
        break;
      case "confused":
        emoji = "\u{1F615}";
        break;
      case "heart":
        emoji = "\u2764\uFE0F";
        break;
      case "hooray":
        emoji = "\u{1F389}";
        break;
      case "rocket":
        emoji = "\u{1F680}";
        break;
      case "eyes":
        emoji = "\u{1F440}";
        break;
    }
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.reactions.createForIssueComment({
        owner: params.owner,
        repo: params.repo,
        comment_id: params.commentId,
        content: params.content
      });
      return result.data;
    }, {
      name: "Add Issue Reaction",
      params,
      properties: [
        {
          label: "Repo",
          text: params.repo
        },
        {
          label: "Comment",
          text: `#${params.commentId}`
        },
        {
          label: "reaction",
          text: emoji
        }
      ]
    }, onError);
  }
};
__name(_Reactions, "Reactions");
var Reactions = _Reactions;

// src/compound.ts
var _Compound = class _Compound {
  constructor(runTask, issues, reactions) {
    this.runTask = runTask;
    this.issues = issues;
    this.reactions = reactions;
  }
  createIssueCommentWithReaction(key, params) {
    return this.runTask(key, async () => {
      const comment = await this.issues.createComment(`Comment on Issue #${params.issueNumber}`, params);
      await this.reactions.createForIssueComment(`React with ${params.reaction}`, {
        owner: params.owner,
        repo: params.repo,
        commentId: comment.id,
        content: params.reaction
      });
      return comment;
    }, {
      name: "Create Issue Comment",
      params,
      properties: [
        {
          label: "Repo",
          text: params.repo
        },
        {
          label: "Issue",
          text: `#${params.issueNumber}`
        }
      ]
    }, onError);
  }
};
__name(_Compound, "Compound");
var Compound = _Compound;

// src/orgs.ts
var _Orgs = class _Orgs {
  constructor(runTask) {
    this.runTask = runTask;
  }
  updateWebhook(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.orgs.updateWebhook({
        org: params.org,
        hook_id: params.hookId,
        config: {
          content_type: "json",
          url: params.url,
          secret: params.secret
        },
        add_events: params.addEvents
      });
      return result.data;
    }, {
      name: "Update Org Webhook",
      params,
      properties: [
        {
          label: "Org",
          text: params.org
        },
        {
          label: "Hook ID",
          text: String(params.hookId)
        }
      ]
    }, onError);
  }
  createWebhook(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.orgs.createWebhook({
        org: params.org,
        name: "web",
        config: {
          content_type: "json",
          url: params.url,
          secret: params.secret
        },
        events: params.events
      });
      return result.data;
    }, {
      name: "Create Org Webhook",
      params,
      properties: [
        {
          label: "Org",
          text: params.org
        },
        {
          label: "Events",
          text: params.events.join(", ")
        }
      ]
    }, onError);
  }
  listWebhooks(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.orgs.listWebhooks({
        org: params.org
      });
      return result.data;
    }, {
      name: "List Org Webhooks",
      params,
      properties: [
        {
          label: "Org",
          text: params.org
        }
      ]
    }, onError);
  }
};
__name(_Orgs, "Orgs");
var Orgs = _Orgs;

// src/git.ts
var _Git = class _Git {
  constructor(runTask) {
    this.runTask = runTask;
  }
  createBlob(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.createBlob({
        owner: params.owner,
        repo: params.repo,
        content: params.content,
        encoding: params.encoding
      });
      return result.data;
    }, {
      name: "Create Blob",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Content",
          text: params.content
        }
      ]
    }, onError);
  }
  getBlob(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.getBlob({
        owner: params.owner,
        repo: params.repo,
        file_sha: params.fileSHA
      });
      return result.data;
    }, {
      name: "Get Blob",
      params,
      properties: [
        ...repoProperties(params)
      ]
    }, onError);
  }
  createCommit(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.createCommit({
        ...params
      });
      return result.data;
    }, {
      name: "Create Commit",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Message",
          text: params.message
        },
        {
          label: "Tree",
          text: params.tree
        }
      ]
    }, onError);
  }
  getCommit(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.getCommit({
        owner: params.owner,
        repo: params.repo,
        commit_sha: params.commitSHA
      });
      return result.data;
    }, {
      name: "Get Commit",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Commit SHA",
          text: params.commitSHA
        }
      ]
    }, onError);
  }
  listMatchingRefs(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.listMatchingRefs(params);
      return result.data;
    }, {
      name: "List Matching References",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Ref",
          text: params.ref
        }
      ]
    }, onError);
  }
  getRef(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.getRef(params);
      return result.data;
    }, {
      name: "Get Reference",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Ref",
          text: params.ref
        }
      ]
    }, onError);
  }
  createRef(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.createRef(params);
      return result.data;
    }, {
      name: "Create Reference",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Ref",
          text: params.ref
        },
        {
          label: "SHA",
          text: params.ref
        }
      ]
    }, onError);
  }
  updateRef(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.updateRef(params);
      return result.data;
    }, {
      name: "Update Reference",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Ref",
          text: params.ref
        },
        {
          label: "SHA",
          text: params.ref
        }
      ]
    }, onError);
  }
  deleteRef(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.deleteRef(params);
      return result.data;
    }, {
      name: "Delete Reference",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Ref",
          text: params.ref
        }
      ]
    }, onError);
  }
  createTag(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.createTag(params);
      return result.data;
    }, {
      name: "Create Tag",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Tag",
          text: params.tag
        },
        {
          label: "Message",
          text: params.message
        },
        {
          label: "Object",
          text: params.object
        },
        {
          label: "Tag Type",
          text: params.type
        }
      ]
    }, onError);
  }
  getTag(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.getTag({
        owner: params.owner,
        repo: params.repo,
        tag_sha: params.tagSHA
      });
      return result.data;
    }, {
      name: "Get Tag",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Tag SHA",
          text: params.tagSHA
        }
      ]
    }, onError);
  }
  createTree(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.createTree(params);
      return result.data;
    }, {
      name: "Create Tree",
      params,
      properties: [
        ...repoProperties(params)
      ]
    }, onError);
  }
  getTree(key, params) {
    return this.runTask(key, async (client, task) => {
      const result = await client.rest.git.getTree({
        owner: params.owner,
        repo: params.repo,
        tree_sha: params.treeSHA,
        recursive: params.recursive
      });
      return result.data;
    }, {
      name: "Get Tree",
      params,
      properties: [
        ...repoProperties(params),
        {
          label: "Tree SHA",
          text: params.treeSHA
        }
      ]
    }, onError);
  }
};
__name(_Git, "Git");
var Git = _Git;

// src/index.ts
var _Github = class _Github {
  constructor(options) {
    this.options = options;
    this.createIssue = this.issues.create;
    this.addIssueAssignees = this.issues.addAssignees;
    this.addIssueLabels = this.issues.addLabels;
    this.createIssueComment = this.issues.createComment;
    this.getIssue = this.issues.get;
    this.getRepo = this.repos.get;
    this.updateWebhook = this.repos.updateWebhook;
    this.createWebhook = this.repos.createWebhook;
    this.listWebhooks = this.repos.listWebhooks;
    this.addIssueCommentReaction = this.reactions.createForIssueComment;
    this.createIssueCommentWithReaction = this.compound.createIssueCommentWithReaction;
    this.updateOrgWebhook = this.orgs.updateWebhook;
    this.createOrgWebhook = this.orgs.createWebhook;
    this.listOrgWebhooks = this.orgs.listWebhooks;
    this.createBlob = this.git.createBlob;
    this.getBlob = this.git.getBlob;
    this.createCommit = this.git.createCommit;
    this.getCommit = this.git.getCommit;
    this.listMatchingReferences = this.git.listMatchingRefs;
    this.getReference = this.git.getRef;
    this.createReference = this.git.createRef;
    this.updateReference = this.git.updateRef;
    this.deleteReference = this.git.deleteRef;
    this.createTag = this.git.createTag;
    this.getTag = this.git.getTag;
    this.createTree = this.git.createTree;
    this.getTree = this.git.getTree;
    if (Object.keys(options).includes("token") && !options.token) {
      throw `Can't create GitHub integration (${options.id}) as token was undefined`;
    }
    this._options = options;
    this._repoSource = createRepoEventSource(this);
    this._orgSource = createOrgEventSource(this);
    this._repoTrigger = createRepoTrigger(this._repoSource);
    this._orgTrigger = createOrgTrigger(this._orgSource);
  }
  get id() {
    return this.options.id;
  }
  get metadata() {
    return {
      name: "GitHub",
      id: "github"
    };
  }
  get authSource() {
    return this._options.token ? "LOCAL" : "HOSTED";
  }
  cloneForRun(io, connectionKey, auth) {
    const github = new _Github(this._options);
    github._io = io;
    github._connectionKey = connectionKey;
    github._client = createClientFromOptions(this._options, auth);
    return github;
  }
  get sources() {
    return {
      repo: this._repoSource,
      org: this._orgSource
    };
  }
  get triggers() {
    return {
      repo: this._repoTrigger,
      org: this._orgTrigger
    };
  }
  runTask(key, callback, options, errorCallback) {
    if (!this._io)
      throw new Error("No IO");
    if (!this._connectionKey)
      throw new Error("No connection key");
    return this._io.runTask(key, (task, io) => {
      if (!this._client)
        throw new Error("No client");
      return callback(this._client, task, io);
    }, {
      icon: "github",
      retry: retry.standardBackoff,
      ...options ?? {},
      connectionKey: this._connectionKey
    }, errorCallback);
  }
  get issues() {
    return new Issues(this.runTask.bind(this));
  }
  get repos() {
    return new Repos(this.runTask.bind(this));
  }
  get reactions() {
    return new Reactions(this.runTask.bind(this));
  }
  get compound() {
    return new Compound(this.runTask.bind(this), this.issues, this.reactions);
  }
  get orgs() {
    return new Orgs(this.runTask.bind(this));
  }
  get git() {
    return new Git(this.runTask.bind(this));
  }
};
__name(_Github, "Github");
var Github = _Github;
function createClientFromOptions(options, auth) {
  if (Object.keys(options).includes("token") && !options.token) {
    throw `Can't create GitHub integration (${options.id}) as token was undefined`;
  }
  if (options.token) {
    return new Octokit({
      auth: options.token,
      request: options.octokitRequest,
      retry: {
        enabled: false
      }
    });
  }
  if (!auth) {
    throw new Error("No auth");
  }
  return new Octokit({
    auth: auth.accessToken,
    request: options.octokitRequest,
    retry: {
      enabled: false
    }
  });
}
__name(createClientFromOptions, "createClientFromOptions");
var onIssue = {
  name: "issues",
  title: "On issue",
  source: "github.com",
  icon: "github",
  examples: [
    issueOpened,
    issueAssigned
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => issueProperties2(payload)
};
var onIssueOpened = {
  name: "issues",
  title: "On issue opened",
  source: "github.com",
  icon: "github",
  filter: {
    action: [
      "opened"
    ]
  },
  examples: [
    issueOpened
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => issueProperties2(payload)
};
var onIssueAssigned = {
  name: "issues",
  title: "On issue assigned",
  source: "github.com",
  icon: "github",
  filter: {
    action: [
      "assigned"
    ]
  },
  examples: [
    issueAssigned
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => [
    ...issueProperties2(payload),
    {
      label: "Assignee",
      text: payload.assignee?.login ?? "none",
      url: payload.assignee?.html_url
    }
  ]
};
var onIssueComment = {
  name: "issue_comment",
  title: "On issue comment",
  source: "github.com",
  icon: "github",
  examples: [
    issueCommentCreated
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => [
    ...issueProperties2(payload),
    {
      label: "Comment body",
      text: truncate(payload.comment.body, 40),
      url: payload.comment.html_url
    }
  ]
};
function issueProperties2(payload) {
  return [
    {
      label: "Issue",
      text: `#${payload.issue.number}: ${payload.issue.title}`,
      url: payload.issue.html_url
    },
    {
      label: "Author",
      text: payload.sender.login,
      url: payload.sender.html_url
    }
  ];
}
__name(issueProperties2, "issueProperties");
var onStar = {
  name: "star",
  title: "On star",
  source: "github.com",
  icon: "github",
  examples: [
    starredRepo
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => starProperties(payload)
};
var onNewStar = {
  name: "star",
  title: "On new star",
  source: "github.com",
  icon: "github",
  filter: {
    action: [
      "created"
    ]
  },
  examples: [
    starredRepo
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => starProperties(payload)
};
function starProperties(payload) {
  return [
    {
      label: "Repo",
      text: `${payload.repository.name}`,
      url: payload.repository.html_url
    },
    {
      label: "Author",
      text: payload.sender.login,
      url: payload.sender.html_url
    },
    {
      label: "Star count",
      text: `${payload.repository.stargazers_count}`,
      url: payload.repository.stargazers_url
    }
  ];
}
__name(starProperties, "starProperties");
var onNewRepository = {
  name: "repository",
  title: "On new repository",
  source: "github.com",
  icon: "github",
  filter: {
    action: [
      "created"
    ]
  },
  parsePayload: (payload) => payload
};
var onNewBranchOrTag = {
  name: "create",
  title: "On new branch or tag",
  source: "github.com",
  icon: "github",
  parsePayload: (payload) => payload,
  runProperties: (payload) => branchTagProperties(payload)
};
var onNewBranch = {
  name: "create",
  title: "On new branch tag",
  source: "github.com",
  icon: "github",
  filter: {
    ref_type: [
      "branch"
    ]
  },
  examples: [
    newBranch
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => branchTagProperties(payload)
};
function branchTagProperties(payload) {
  return [
    {
      label: "Repo",
      text: payload.repository.name,
      url: payload.repository.html_url
    },
    {
      label: payload.ref_type === "branch" ? "Branch" : "Tag",
      text: payload.ref
    }
  ];
}
__name(branchTagProperties, "branchTagProperties");
var onPush = {
  name: "push",
  title: "On push",
  source: "github.com",
  icon: "github",
  examples: [
    push
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => {
    let props = [
      {
        label: "Repo",
        text: payload.repository.name,
        url: payload.repository.html_url
      },
      {
        label: "Branch",
        text: payload.ref
      },
      {
        label: "Pusher",
        text: payload.pusher.name
      },
      {
        label: "Commits",
        text: `${payload.commits.length}`
      }
    ];
    if (payload.head_commit) {
      props.push({
        label: "Head commit",
        text: payload.head_commit.id,
        url: payload.head_commit.url
      });
    }
    return props;
  }
};
var onPullRequest = {
  name: "pull_request",
  title: "On pull request",
  source: "github.com",
  icon: "github",
  examples: [
    pullRequestOpened
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => [
    {
      label: "Repo",
      text: payload.repository.name,
      url: payload.repository.html_url
    },
    {
      label: "action",
      text: payload.action
    },
    {
      label: "Number",
      text: `${payload.number}`
    },
    {
      label: "Title",
      text: payload.pull_request.title
    },
    {
      label: "Author",
      text: payload.pull_request.user.login,
      url: payload.pull_request.user.html_url
    },
    {
      label: "Commits",
      text: `${payload.pull_request.commits}`
    },
    {
      label: "Body",
      text: truncate(payload.pull_request.body ?? "none", 40)
    }
  ]
};
var onPullRequestReview = {
  name: "pull_request_review",
  title: "On pull request review",
  source: "github.com",
  icon: "github",
  examples: [
    pullRequestReviewSubmitted
  ],
  parsePayload: (payload) => payload,
  runProperties: (payload) => [
    {
      label: "Repo",
      text: payload.repository.name,
      url: payload.repository.html_url
    },
    {
      label: "action",
      text: payload.action
    },
    {
      label: "Author",
      text: payload.review.user.login,
      url: payload.review.user.html_url
    },
    {
      label: "Body",
      text: truncate(payload.review.body ?? "none", 40)
    },
    {
      label: "PR Number",
      text: `${payload.pull_request.number}`
    },
    {
      label: "PR Title",
      text: payload.pull_request.title
    }
  ]
};
var events = {
  /** When any action is performed on an issue  */
  onIssue,
  /** When an issue is opened  */
  onIssueOpened,
  /** When an issue is assigned  */
  onIssueAssigned,
  /** When an issue is commented on  */
  onIssueComment,
  /** When a repo is starred or unstarred  */
  onStar,
  /** When a repo is starred  */
  onNewStar,
  /** When a new repo is created  */
  onNewRepository,
  /** When a new branch or tag is created  */
  onNewBranchOrTag,
  /** When a new branch is created  */
  onNewBranch,
  /** When a push is made to a repo  */
  onPush,
  /** When activity occurs on a pull request. Doesn't include reviews, issues or comments. */
  onPullRequest,
  /** When Pull Request review has activity. */
  onPullRequestReview
};
function createRepoTrigger(source) {
  return ({ event, owner, repo }) => {
    return new ExternalSourceTrigger({
      event,
      params: {
        owner,
        repo
      },
      source,
      options: {}
    });
  };
}
__name(createRepoTrigger, "createRepoTrigger");
function createOrgTrigger(source) {
  return ({ event, org }) => {
    return new ExternalSourceTrigger({
      event,
      params: {
        org
      },
      source,
      options: {}
    });
  };
}
__name(createOrgTrigger, "createOrgTrigger");
function isRequestError(error) {
  return typeof error === "object" && error !== null && "status" in error;
}
__name(isRequestError, "isRequestError");
function onError(error) {
  if (!isRequestError(error)) {
    return;
  }
  if (error.status === 403 && error.response) {
    const rateLimitRemaining = error.response.headers["x-ratelimit-remaining"];
    const rateLimitReset = error.response.headers["x-ratelimit-reset"];
    if (rateLimitRemaining === "0" && rateLimitReset) {
      const resetDate = new Date(Number(rateLimitReset) * 1e3);
      return {
        retryAt: resetDate,
        error
      };
    }
  }
}
__name(onError, "onError");

export { Github, events, isRequestError, onError };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.mjs.map